@@ -11,13 +11,14 @@ else
     WITH_OPENMP=1
 fi
 
-cmake \
+cmake ${CMAKE_ARGS} \
     -DCMAKE_PREFIX_PATH=$PREFIX \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_BUILD_TYPE=Release \
     -DCMAKE_INSTALL_LIBDIR=lib \
     -DBUILD_SHARED_LIBS=ON \
     -DBUILD_STATIC_LIBS=OFF \
+    -DCMAKE_C_STANDARD=11 \
     -DEXAMPLES_ENABLE_C=ON \
     -DEXAMPLES_INSTALL=OFF \
     -DENABLE_OPENMP=$WITH_OPENMP \
